Page 83 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 83

Home

    Revelation 19:2 as, "the great whore, which did corrupt
    the earth with her fornication," signifies universal

    idolatry.

    This would indicate that Mystery Babylon will be a
    world leader in a return to a pagan worship of nature that
    denies God as creator, exactly as we see in the New Age
    Movement. More than any other single evil, it was
    idolatry that led to the downfall of the nation of Israel.
    The Bible condemns idolatry as evil because, it not only
    denies God as creator, and regards man on the level of
    animals, it often leads to the shedding of the blood of
    innocent human beings.

    ae

    Babylon's leaders were condemned for using sorceries
    (the assistance of evil spirits) to deceive the nations, "for
    by thy sorceries were all nations deceived" Revelation
    18:23.

    Babylon is also described as the instigator of mass
    murder with a Satanic hatred of those who believe in

    God. "And in her was found the blood of prophets, and
    of saints, and of all that were slain upon the earth"
    Revelation 18:24. The Apostle John gave this witness in
    Revelation 17:6, "And I saw the woman drunken with

    The picture of Mystery Babylon is so terrible that the
    first mention of it in Revelation 14:8 gives the good news
    first, "And there followed another angel, saying, Babylon
    is fallen, is fallen, that great city, because she made all
    the nations drink of the wine of the wrath of her

    78

    The Secret Side of History

    the blood of the saints, and with the blood of the martyrs

    of Jesus:..."